---
name: Bug report
about: Report an error that you've encountered.
labels: 'category: bug'
---

### Environment information

- OS: macOS / linux / win
- Python Version: x.x.x
- `ape` and plugin versions:

```sh
$ ape --version
# ...copy and paste result of above command here...

$ ape plugins list
# ...copy and paste result of above command here...
```

- Contents of your `ape-config.yaml` (NOTE: do not post anything private like RPC urls or secrets!):

```sh
$ cat ape-config.yaml
# ...copy and paste result of above command here...
```

### What went wrong?

Please include information like:

- what command you ran
- the code that caused the failure (see [this link](https://help.github.com/articles/basic-writing-and-formatting-syntax/) for help with formatting code)
- full output of the error you received

### How can it be fixed?

Fill this in if you have ideas on how the bug could be fixed.
